Methods
addListener (VoidCallback listener )
→ void
Register a closure to be called when the object changes.
inherited
dispose ()
→ void
Discards any resources used by the object.
override
init ()
→ void
A callback after ViewModel is constructed.
The event is called by default every time the
ViewModel view dependencies are updated.
Set initOnce of the ViewModelBuilder builder to true to ignore
dependencies updates.
noSuchMethod (Invocation invocation )
→ dynamic
Invoked when a nonexistent method or property is accessed.
inherited
notifyListeners ()
→ void
Call all the registered listeners.
override
onAfterBuild ()
→ void
A callback when the addPostFrameCallback method is called.
onBuild ()
→ void
A callback when the build method is called.
onDispose ()
→ void
A callback when the view disposed.
removeListener (VoidCallback listener )
→ void
Remove a previously registered closure from the list of closures that are
notified when the object changes.
inherited
toString ()
→ String
A string representation of this object.
inherited